@@ -1,17 +1,18 @@
 from typing import Optional
 
+import tensorflow as tf
 from tensorflow.keras import backend as K
 from tensorflow.keras import constraints
 from tensorflow.keras import initializers
 from tensorflow.keras import regularizers
 from tensorflow.keras.layers import InputSpec
 from tensorflow.python.keras.layers.recurrent import LSTM, LSTMCell
-from tensorflow.python.keras.saving.saved_model import layer_serialization
 from tensorflow.python.training.tracking import data_structures
 
 from sknlp.typing import WeightRegularizer, WeightInitializer, WeightConstraint
 
 
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class LSTMPCell(LSTMCell):
     """
     Long-Short Term Memory Projected (LSTMP) network cell with cell clip.
@@ -196,14 +197,19 @@ class LSTMPCell(LSTMCell):
             "projection_size": self.projection_size,
             "recurrent_clip": self.recurrent_clip,
             "projection_clip": self.projection_clip,
-            "projection_initializer": self.projection_initializer,
-            "projection_regularizer": self.projection_regularizer,
-            "projection_constraint": self.projection_constraint,
+            "projection_initializer": initializers.serialize(
+                self.projection_initializer
+            ),
+            "projection_regularizer": regularizers.serialize(
+                self.projection_regularizer
+            ),
+            "projection_constraint": constraints.serialize(self.projection_constraint),
         }
         base_config = super().get_config()
         return {**base_config, **config}
 
 
+@tf.keras.utils.register_keras_serializable(package="sknlp")
 class LSTMP(LSTM):
     """
 
@@ -360,6 +366,7 @@ class LSTMP(LSTM):
             **kwargs
         )
         self.activity_regularizer = regularizers.get(activity_regularizer)
+        self.supports_masking = True
         self.input_spec = [InputSpec(ndim=3)]
 
     @property
@@ -386,6 +393,14 @@ class LSTMP(LSTM):
     def projection_clip(self):
         return self.cell.projection_clip
 
+    def compute_mask(self, inputs, mask):
+        output_mask = mask
+        if self.return_state:
+            state_mask = [None for _ in self.states]
+            return [output_mask] + state_mask
+        else:
+            return output_mask
+
     def get_config(self):
         base_config = super().get_config()
         return {**base_config, **self.cell.get_config()}
